@@ -27,15 +27,15 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "latexgenerator.h"
 
+using std::ostringstream;
+using std::string;
+
 namespace highlight
 {
 
 LatexGenerator::LatexGenerator()
-    : CodeGenerator ( LATEX ),
-      replaceQuotes ( false ),
-      disableBabelShortHand ( false ),
-      prettySymbols ( false ),
-      beamerMode ( false )
+    : CodeGenerator ( LATEX )
+      
 {
     // avoid "Underfull \hbox (badness 10000)" warnings
     newLineTag = "\\\\\n";
@@ -188,7 +188,7 @@ void LatexGenerator::initOutputTags()
     openTags.push_back ( "\\hl"+STY_NAME_ERM+"{" );
 
     for (unsigned int i=0; i<NUMBER_BUILTIN_STATES; i++ ) {
-        closeTags.push_back ( "}" );
+        closeTags.emplace_back("}" );
     }
 }
 
@@ -224,7 +224,7 @@ string LatexGenerator::getAttributes ( const string & elemName,
         s  <<"}";
     }
 
-    string customStyle(elem.getCustomStyle());
+    string customStyle(elem.getCustomAttribute());
     if (!customStyle.empty()) {
         s << customStyle;
     }
@@ -349,10 +349,10 @@ string LatexGenerator::getStyleDefinition()
         os << getAttributes ( STY_NAME_ERR, docStyle.getErrorStyle() );
         os << getAttributes ( STY_NAME_ERM, docStyle.getErrorMessageStyle() );
 
-        KeywordStyles styles = docStyle.getKeywordStyles();
-        for ( KSIterator it=styles.begin(); it!=styles.end(); it++ ) {
-            os << getAttributes ( it->first, it->second );
+        for ( const auto &[first, second] : docStyle.getKeywordStyles() ) {
+            os << getAttributes ( first, second );
         }
+
         os << "\\definecolor{bgcolor}{rgb}{"
            << docStyle.getBgColour().getRed ( LATEX ) << ","
            << docStyle.getBgColour().getGreen ( LATEX ) << ","
